Skip to contents

Returns the names (without the service prefix) of all tokens stored for a given service in environment variables.

Usage

af_list_tokens(service = "apifetch")

Arguments

service

A namespace prefix grouping tokens for one API. Default "apifetch".

Value

A character vector of token names, empty if none are found.

Examples

af_list_tokens(service = "BigDataPE")
#>  No tokens found for service "BigDataPE".
#> character(0)