R/tokens.R
af_list_tokens.Rd
Returns the names (without the service prefix) of all tokens stored for a given service in environment variables.
service
af_list_tokens(service = "apifetch")
A namespace prefix grouping tokens for one API. Default "apifetch".
"apifetch"
A character vector of token names, empty if none are found.
af_list_tokens(service = "BigDataPE") #> ℹ No tokens found for service "BigDataPE". #> character(0)